
// Sensitivity study model under confounding bias, confounding parameters uncertain

data {
  int<lower=0> n; 
  real y[n]; 
  real age[n];
  real bmu;
  real<lower=0> bsig;
  real gamma0mu;
  real<lower=0> gamma0sig;
}
parameters {
  real beta0;
  real beta1;
  real beta2;
  real<lower=0, upper=1> load[n]; 
  real<lower=0> sigma;
  real gamma1;
}
transformed parameters {
  real mu[n];
  real mul[n];
  real sigmal[n];
  
  for (i in 1:n){
    mu[i] = beta0 + beta1*age[i] + beta2*load[i];
    mul[i] = .5 + gamma1*age[i];
    sigmal[i] = .25;
  }

}
model {
  y ~ normal(mu, sigma);
   beta2 ~ normal(bmu, bsig); // Sensitivity study parameters
  gamma1 ~ normal(gamma0mu, gamma0sig); // Sensitivity study parameters
  for(i in 1:n)
  load[i] ~ normal(mul[i], sigmal[i]) T[0,1];
}
