
// Sensitivity study model under selection bias, sensitivity parameters uncertain

data {
  int<lower=0> n; 
  real y[n]; 
  real age[n];
  real bmu;
  real<lower=0> bsig;
  real lmumean;
  real lmusig; 
}
parameters {
  real beta0;
  real beta1;
  real beta2; 
  real<lower=0, upper=1> load[n]; 
  real<lower=0> sigma;
  real lmu;
  
}
transformed parameters {
  real mu[n];

  for (i in 1:n){
    mu[i] = beta0 + beta1*age[i] + beta2*load[i];
  }

}
model {
  y ~ normal(mu, sigma);
   beta2 ~ normal(bmu, bsig); // Sensitivity study parameter
  
  for(i in 1:n)
    load[i] ~ normal(lmu, .25) T[0,1];
  
    lmu ~ normal(lmumean, lmusig); // Sensitivity study parameter
}
