
#####################################
### HELPER FUNCTIONS              ###
### FOR GENERATING DATA AND       ###
### CALCULATING OUTPUT QUANTITIES ###        
#####################################
#DATA GENERATING FUNCTIONS ----

#generate simulated data with correct distributions - no bias
gen_simdat <- function(agepred, loadpred = NULL){
  age <- rep(agepred, nsim)
  if(is.null(loadpred)==T){
    load <- rtnorm(nsim, muload, sdload, minload, maxload)     
  }else{
    load <- rep(loadpred, nsim) 
  }
  volt <- voltfun(age, load)
  simdat <- data.frame(age, volt, load=load)
  return(simdat)
}

# generate observed data with selection or selection + confounding bias
gen_testdata <- function(type="select"){
  if(type=="select"){
    age <- runif(ntestdata, minage, maxage)
    load <- rtnorm(ntestdata, muload + 2*sdload, sdload, minload, maxload) #selection bias on load
    volt <- voltfun(age, load)
    testdata <- data.frame(age, volt, load=load)
    testdata$set <- "f"
  }
  if(type=="confound"){
    age <- runif(ntestdata, minage, maxage)
    load <- rtnorm(ntestdata, muload + .02*age, sdload, minload, maxload) #confounding bias on load
    volt <- voltfun(age, load)
    testdata <- data.frame(age, volt, load=load)
    testdata$set <- "f"
  }
  if(type=="unbiased"){
    age <- runif(ntestdata, minage, maxage)
    load <- rtnorm(ntestdata, muload, sdload, minload, maxload) #no bias on load
    volt <- voltfun(age, load)
    testdata <- data.frame(age, volt, load=load)
    testdata$set <- "f"
  }
  return(testdata)
}

# CALCULATE OUTPUT QUANTITIES -----

# generate voltage samples from fitted model
gen_dist <- function(samps, simdat){
  return(sapply(1:length(samps$beta0), function(jj)
    rnorm(nrow(simdat), samps$beta0[jj] +samps$beta1[jj]*simdat$age + 
            samps$beta2[jj]*simdat$load, samps$sigma[jj])))
}

#calculate reliability and confidence bounds given confidence bounds on distribution ----
calc_rel <- function(dist_summary, req){
  out <- c(length(which(dist_summary[2,] > req))/length(dist_summary[2,]),
           length(which(dist_summary[1,] > req))/length(dist_summary[2,]),
           length(which(dist_summary[3,] > req))/length(dist_summary[2,]))
  names(out) <- c("est", "lower", "upper")
  return(out)
}

# calculate quantiles of CDF 
make_distqs <- function(dist){
  dist_summary <- matrix(NA, nrow=3, ncol=ncol(dist))
  for(nn in 1:ncol(dist)){
    qs <- apply(dist, 1, quantile, probs=nn/ncol(dist))
    dist_summary[,nn] <- rbind(dist[which.min(abs(qs - quantile(qs, .025))),nn],
                               dist[which.min(abs(qs - quantile(qs, .5))),nn],
                               dist[which.min(abs(qs - quantile(qs, .975))),nn])
  }
  return(dist_summary)
}

